@@ -55,8 +55,7 @@ proc_filelist()
       -name "COPYING" -o \
       -name "INSTALL" -o \
       -name "README" -o \
-      -name "README.fr" -o \
-      -name "README.de" -o \
+      -name "README.*" -o \
       -name "ChangeLog" \
    ")"`
 }
