@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -85,7 +85,7 @@ reset_game_area (void)
 int
 create_game_area (void)
 {
-  int x, y, i, test;
+  int x, y, i;
 
   CURRENT_AREA = malloc_in_big_data_bottom
     (CURRENT_AREA_W * CURRENT_AREA_H * sizeof (PLACE));
@@ -94,20 +94,19 @@ create_game_area (void)
     {
       i = 0;
       for (y = 0; y < CURRENT_AREA_H; ++y)
-	for (x = 0; x < CURRENT_AREA_W; ++x)
-	  {
-	    CURRENT_AREA[i].mesh = NULL;
-	    CURRENT_AREA[i].fighter = NULL;
-	    i++;
-	  }
+        for (x = 0; x < CURRENT_AREA_W; ++x)
+          {
+            CURRENT_AREA[i].mesh = NULL;
+            CURRENT_AREA[i].fighter = NULL;
+            i++;
+          }
       for (i = 0; i < CURRENT_MESH_SIZE; ++i)
-	for (y = 0; y < CURRENT_MESH[i].side.size; ++y)
-	  for (x = 0; x < CURRENT_MESH[i].side.size; ++x)
-	    {
-	      CURRENT_AREA[(CURRENT_MESH[i].y + y) * CURRENT_AREA_W
-			   + CURRENT_MESH[i].x + x].mesh = CURRENT_MESH + i;
-	      test = CURRENT_MESH[i].info[0].state.grad;
-	    }
+        for (y = 0; y < CURRENT_MESH[i].side.size; ++y)
+          for (x = 0; x < CURRENT_MESH[i].side.size; ++x)
+            {
+              CURRENT_AREA[(CURRENT_MESH[i].y + y) * CURRENT_AREA_W
+                           + CURRENT_MESH[i].x + x].mesh = CURRENT_MESH + i;
+            }
     }
 
   return (CURRENT_AREA ? 0 : -1);
