@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -113,7 +113,6 @@ lw_capture_dump_menu ()
 {
   int result = 1;
   static int last_dump_time = 0;
-  int dummy;
 
   /*
    * We don't dump stuff if the last dump is too recent.
@@ -129,9 +128,9 @@ lw_capture_dump_menu ()
        * We do nothing if we're not in capture mode
        */
       if (LW_CAPTURE_MODE)
-	{
-	  lw_capture_dump_game ();
-	}
+        {
+          lw_capture_dump_game ();
+        }
     }
 
   /*
@@ -141,14 +140,14 @@ lw_capture_dump_menu ()
   if (key[KEY_F9])
     {
       while (key[KEY_F9])
-	{
-	  /*
-	   * Force a all to poll_keyboard if needed
-	   */
-	  dummy = keypressed ();
+        {
+          /*
+           * Force a all to poll_keyboard if needed
+           */
+          keypressed ();
 
-	  rest (10);
-	}
+          rest (10);
+        }
       LW_CAPTURE_MODE = !LW_CAPTURE_MODE;
     }
 
@@ -176,7 +175,7 @@ lw_capture_dump_game ()
        * Prepare a nice filename
        */
       LW_MACRO_SPRINTF1 (buffer, LW_CAPTURE_FILENAME_FORMAT_STRING,
-			 frame_number++);
+                         frame_number++);
 
       /*
        * Log on the console
@@ -189,20 +188,20 @@ lw_capture_dump_game ()
        * Create a sub-bitmap with the right size
        */
       screenshot =
-	create_sub_bitmap (screen, 0, PAGE_FLIP_H, SCREEN_W, SCREEN_H);
+        create_sub_bitmap (screen, 0, PAGE_FLIP_H, SCREEN_W, SCREEN_H);
 
       if (screenshot)
-	{
-	  /*
-	   * Write to disk
-	   */
-	  result = !save_bitmap (buffer, screenshot, GLOBAL_PALETTE);
-	  destroy_bitmap (screenshot);
-	}
+        {
+          /*
+           * Write to disk
+           */
+          result = !save_bitmap (buffer, screenshot, GLOBAL_PALETTE);
+          destroy_bitmap (screenshot);
+        }
       else
-	{
-	  result = 0;
-	}
+        {
+          result = 0;
+        }
 
       display_success (result);
     }
