@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -121,6 +121,8 @@
 #define LABEL_MIN_MAP_RES "MIN_MAP_RES"
 #define LABEL_USE_DEFAULT_TEXTURE "USE_DEFAULT_TEXTURE"
 #define LABEL_ALLOW_NETWORK_BOTS "ALLOW_NETWORK_BOTS"
+#define LABEL_LW6_ADVERTISING_SKIP "LW6_ADVERTISING_SKIP"
+#define LABEL_LW6_ADVERTISING_DONE "LW6_ADVERTISING_DONE"
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
@@ -169,6 +171,8 @@ char CONFIG_PASSWORD[PASSWORD_SIZE + 1];
 int CONFIG_MIN_MAP_RES;
 int CONFIG_USE_DEFAULT_TEXTURE;
 int CONFIG_ALLOW_NETWORK_BOTS;
+int CONFIG_LW6_ADVERTISING_SKIP;
+int CONFIG_LW6_ADVERTISING_DONE;
 
 LW_NETCONF LW_CONFIG_CURRENT_RULES;
 
@@ -179,6 +183,7 @@ LW_NETCONF LW_CONFIG_CURRENT_RULES;
 int DISPLAY_DELAY_MIN[9] = { 0, 10, 15, 20, 25,
   33, 40, 55, 100
 };
+
 int LOGIC_DELAY_MIN[9] = { 0, 1, 2, 5, 10,
   15, 20, 33, 50
 };
@@ -290,15 +295,13 @@ load_default_options (void)
   CONFIG_JOYSTICK_ON = 1;
   CONFIG_PAGE_FLIP = 0;
   CONFIG_LANGUAGE = LW_LANG_LANGUAGE_AUTO;
-#ifdef ASM
   /*
-   * We activate waves only if assembly code is available,
-   * else it's not a good idea for it's too slow.
+   * Previous versions used to have waves disabled on behalf
+   * of performance, with today computers being 100 times faster
+   * than primitive stuff that ran LW in the first place, one
+   * might admit this is on by default. Looks better.
    */
-  CONFIG_WAVE_ON = STARTUP_ASM ? 1 : 0;
-#else
-  CONFIG_WAVE_ON = 0;
-#endif
+  CONFIG_WAVE_ON = 1;
 
   CONFIG_FRAMES_PER_SEC_LIMIT = 6;
   CONFIG_ROUNDS_PER_SEC_LIMIT = 4;
@@ -310,6 +313,15 @@ load_default_options (void)
 
   CONFIG_USE_DEFAULT_TEXTURE = 1;
 
+  /*
+   * TBH I'm really questionning myself wether I should advertise
+   * for LW6 at this stage. Given the fact, very likely, if I push
+   * something strong, it might be called Liquid War 7. Even numbers
+   * are cursed in the LW series.
+   */
+  CONFIG_LW6_ADVERTISING_SKIP = 1;
+  CONFIG_LW6_ADVERTISING_DONE = 0;
+
   load_default_rules ();
 }
 
@@ -344,150 +356,156 @@ load_disk_options (void)
   if (get_config_int (LABEL_MAIN, LABEL_DUMMY, 0) == DUMMY_VALUE)
     {
       CONFIG_GFX_GAME =
-	get_config_int (LABEL_MAIN, LABEL_GFX_GAME, CONFIG_GFX_GAME);
+        get_config_int (LABEL_MAIN, LABEL_GFX_GAME, CONFIG_GFX_GAME);
       CONFIG_GFX_MENU =
-	get_config_int (LABEL_MAIN, LABEL_GFX_MENU, CONFIG_GFX_MENU);
+        get_config_int (LABEL_MAIN, LABEL_GFX_MENU, CONFIG_GFX_MENU);
       CONFIG_FULLSCREEN =
-	get_config_int (LABEL_MAIN, LABEL_FULLSCREEN, CONFIG_FULLSCREEN);
+        get_config_int (LABEL_MAIN, LABEL_FULLSCREEN, CONFIG_FULLSCREEN);
       CONFIG_VIEWPORT_SIZE =
-	get_config_int (LABEL_MAIN, LABEL_VIEWPORT_SIZE,
-			CONFIG_VIEWPORT_SIZE);
+        get_config_int (LABEL_MAIN, LABEL_VIEWPORT_SIZE,
+                        CONFIG_VIEWPORT_SIZE);
 
       for (i = 0; i < 4; ++i)
-	{
-	  number_string[0] = '0' + i;
+        {
+          number_string[0] = '0' + i;
 
-	  CONFIG_WAVE_NUMBER[i] =
-	    get_config_int (LABEL_WAVE_NUMBER, number_string,
-			    CONFIG_WAVE_NUMBER[i]);
-	  CONFIG_WAVE_AMPLI[i] =
-	    get_config_int (LABEL_WAVE_AMPLI, number_string,
-			    CONFIG_WAVE_AMPLI[i]);
-	  CONFIG_WAVE_SPEED[i] =
-	    get_config_int (LABEL_WAVE_SPEED, number_string,
-			    CONFIG_WAVE_SPEED[i]);
-	}
+          CONFIG_WAVE_NUMBER[i] =
+            get_config_int (LABEL_WAVE_NUMBER, number_string,
+                            CONFIG_WAVE_NUMBER[i]);
+          CONFIG_WAVE_AMPLI[i] =
+            get_config_int (LABEL_WAVE_AMPLI, number_string,
+                            CONFIG_WAVE_AMPLI[i]);
+          CONFIG_WAVE_SPEED[i] =
+            get_config_int (LABEL_WAVE_SPEED, number_string,
+                            CONFIG_WAVE_SPEED[i]);
+        }
 
       CONFIG_BRIGHTNESS =
-	get_config_int (LABEL_MAIN, LABEL_BRIGHTNESS, CONFIG_BRIGHTNESS);
+        get_config_int (LABEL_MAIN, LABEL_BRIGHTNESS, CONFIG_BRIGHTNESS);
       CONFIG_CURSOR_INCREASE_SPEED =
-	get_config_int (LABEL_MAIN, LABEL_CURSOR_INCREASE_SPEED,
-			CONFIG_CURSOR_INCREASE_SPEED);
+        get_config_int (LABEL_MAIN, LABEL_CURSOR_INCREASE_SPEED,
+                        CONFIG_CURSOR_INCREASE_SPEED);
       CONFIG_FIGHTER_ATTACK =
-	get_config_int (LABEL_MAIN, LABEL_FIGHTER_ATTACK,
-			CONFIG_FIGHTER_ATTACK);
+        get_config_int (LABEL_MAIN, LABEL_FIGHTER_ATTACK,
+                        CONFIG_FIGHTER_ATTACK);
       CONFIG_FIGHTER_DEFENSE =
-	get_config_int (LABEL_MAIN, LABEL_FIGHTER_DEFENSE,
-			CONFIG_FIGHTER_DEFENSE);
+        get_config_int (LABEL_MAIN, LABEL_FIGHTER_DEFENSE,
+                        CONFIG_FIGHTER_DEFENSE);
       CONFIG_FIGHTER_NEW_HEALTH =
-	get_config_int (LABEL_MAIN, LABEL_FIGHTER_NEW_HEALTH,
-			CONFIG_FIGHTER_NEW_HEALTH);
+        get_config_int (LABEL_MAIN, LABEL_FIGHTER_NEW_HEALTH,
+                        CONFIG_FIGHTER_NEW_HEALTH);
       CONFIG_NUMBER_INFLUENCE =
-	get_config_int (LABEL_MAIN, LABEL_NUMBER_INFLUENCE,
-			CONFIG_NUMBER_INFLUENCE);
+        get_config_int (LABEL_MAIN, LABEL_NUMBER_INFLUENCE,
+                        CONFIG_NUMBER_INFLUENCE);
       CONFIG_SFX_VOLUME =
-	get_config_int (LABEL_MAIN, LABEL_SFX_VOLUME, CONFIG_SFX_VOLUME);
+        get_config_int (LABEL_MAIN, LABEL_SFX_VOLUME, CONFIG_SFX_VOLUME);
       CONFIG_CLICK_VOLUME =
-	get_config_int (LABEL_MAIN, LABEL_CLICK_VOLUME, CONFIG_CLICK_VOLUME);
+        get_config_int (LABEL_MAIN, LABEL_CLICK_VOLUME, CONFIG_CLICK_VOLUME);
       CONFIG_WATER_VOLUME_MENU =
-	get_config_int (LABEL_MAIN, LABEL_WATER_VOLUME_MENU,
-			CONFIG_WATER_VOLUME_MENU);
+        get_config_int (LABEL_MAIN, LABEL_WATER_VOLUME_MENU,
+                        CONFIG_WATER_VOLUME_MENU);
       CONFIG_WATER_VOLUME_GAME =
-	get_config_int (LABEL_MAIN, LABEL_WATER_VOLUME_GAME,
-			CONFIG_WATER_VOLUME_GAME);
+        get_config_int (LABEL_MAIN, LABEL_WATER_VOLUME_GAME,
+                        CONFIG_WATER_VOLUME_GAME);
       CONFIG_MUSIC_VOLUME =
-	get_config_int (LABEL_MAIN, LABEL_MUSIC_VOLUME, CONFIG_MUSIC_VOLUME);
+        get_config_int (LABEL_MAIN, LABEL_MUSIC_VOLUME, CONFIG_MUSIC_VOLUME);
 
       CONFIG_LEVEL_MAP =
-	get_config_int (LABEL_MAIN, LABEL_LEVEL_MAP, CONFIG_LEVEL_MAP);
+        get_config_int (LABEL_MAIN, LABEL_LEVEL_MAP, CONFIG_LEVEL_MAP);
       CONFIG_LEVEL_FG =
-	get_config_int (LABEL_MAIN, LABEL_LEVEL_FG, CONFIG_LEVEL_FG);
+        get_config_int (LABEL_MAIN, LABEL_LEVEL_FG, CONFIG_LEVEL_FG);
       CONFIG_LEVEL_BG =
-	get_config_int (LABEL_MAIN, LABEL_LEVEL_BG, CONFIG_LEVEL_BG);
+        get_config_int (LABEL_MAIN, LABEL_LEVEL_BG, CONFIG_LEVEL_BG);
 
       CONFIG_FIGHTER_NUMBER =
-	get_config_int (LABEL_MAIN, LABEL_FIGHTER_NUMBER,
-			CONFIG_FIGHTER_NUMBER);
+        get_config_int (LABEL_MAIN, LABEL_FIGHTER_NUMBER,
+                        CONFIG_FIGHTER_NUMBER);
 
       for (i = 0; i < 6; ++i)
-	{
-	  number_string[0] = '0' + i;
+        {
+          number_string[0] = '0' + i;
 
-	  CONFIG_KEY_UP[i] =
-	    get_config_int (LABEL_KEY_UP, number_string, CONFIG_KEY_UP[i]);
-	  CONFIG_KEY_LEFT[i] =
-	    get_config_int (LABEL_KEY_LEFT, number_string,
-			    CONFIG_KEY_LEFT[i]);
-	  CONFIG_KEY_DOWN[i] =
-	    get_config_int (LABEL_KEY_DOWN, number_string,
-			    CONFIG_KEY_DOWN[i]);
-	  CONFIG_KEY_RIGHT[i] =
-	    get_config_int (LABEL_KEY_RIGHT, number_string,
-			    CONFIG_KEY_RIGHT[i]);
-	  CONFIG_TEAM_COLOR[i] =
-	    get_config_int (LABEL_TEAM_COLOR, number_string,
-			    CONFIG_TEAM_COLOR[i]);
-	  CONFIG_CONTROL_TYPE[i] =
-	    get_config_int (LABEL_CONTROL_TYPE, number_string,
-			    CONFIG_CONTROL_TYPE[i]);
-	  strncpy (CONFIG_PLAYER_NAME[i],
-		   get_config_string (LABEL_PLAYER_NAME, number_string,
-				      CONFIG_PLAYER_NAME[i]), NAME_SIZE);
-	  CONFIG_PLAYER_NAME[i][NAME_SIZE] = '\0';
-	}
+          CONFIG_KEY_UP[i] =
+            get_config_int (LABEL_KEY_UP, number_string, CONFIG_KEY_UP[i]);
+          CONFIG_KEY_LEFT[i] =
+            get_config_int (LABEL_KEY_LEFT, number_string,
+                            CONFIG_KEY_LEFT[i]);
+          CONFIG_KEY_DOWN[i] =
+            get_config_int (LABEL_KEY_DOWN, number_string,
+                            CONFIG_KEY_DOWN[i]);
+          CONFIG_KEY_RIGHT[i] =
+            get_config_int (LABEL_KEY_RIGHT, number_string,
+                            CONFIG_KEY_RIGHT[i]);
+          CONFIG_TEAM_COLOR[i] =
+            get_config_int (LABEL_TEAM_COLOR, number_string,
+                            CONFIG_TEAM_COLOR[i]);
+          CONFIG_CONTROL_TYPE[i] =
+            get_config_int (LABEL_CONTROL_TYPE, number_string,
+                            CONFIG_CONTROL_TYPE[i]);
+          strncpy (CONFIG_PLAYER_NAME[i],
+                   get_config_string (LABEL_PLAYER_NAME, number_string,
+                                      CONFIG_PLAYER_NAME[i]), NAME_SIZE);
+          CONFIG_PLAYER_NAME[i][NAME_SIZE] = '\0';
+        }
 
       CONFIG_GAME_TIME =
-	get_config_int (LABEL_MAIN, LABEL_GAME_TIME, CONFIG_GAME_TIME);
+        get_config_int (LABEL_MAIN, LABEL_GAME_TIME, CONFIG_GAME_TIME);
       CONFIG_INFO_BAR =
-	get_config_int (LABEL_MAIN, LABEL_INFO_BAR, CONFIG_INFO_BAR);
+        get_config_int (LABEL_MAIN, LABEL_INFO_BAR, CONFIG_INFO_BAR);
       CONFIG_MOUSE_GAP =
-	get_config_int (LABEL_MAIN, LABEL_MOUSE_GAP, CONFIG_MOUSE_GAP);
+        get_config_int (LABEL_MAIN, LABEL_MOUSE_GAP, CONFIG_MOUSE_GAP);
       CONFIG_JOYSTICK_ON =
-	get_config_int (LABEL_MAIN, LABEL_JOYSTICK_ON, CONFIG_JOYSTICK_ON);
+        get_config_int (LABEL_MAIN, LABEL_JOYSTICK_ON, CONFIG_JOYSTICK_ON);
       CONFIG_CPU_ADVANTAGE =
-	get_config_int (LABEL_MAIN, LABEL_CPU_ADVANTAGE,
-			CONFIG_CPU_ADVANTAGE);
+        get_config_int (LABEL_MAIN, LABEL_CPU_ADVANTAGE,
+                        CONFIG_CPU_ADVANTAGE);
       CONFIG_CPU_VS_HUMAN =
-	get_config_int (LABEL_MAIN, LABEL_CPU_VS_HUMAN, CONFIG_CPU_VS_HUMAN);
+        get_config_int (LABEL_MAIN, LABEL_CPU_VS_HUMAN, CONFIG_CPU_VS_HUMAN);
       CONFIG_PAGE_FLIP =
-	get_config_int (LABEL_MAIN, LABEL_PAGE_FLIP, CONFIG_PAGE_FLIP);
+        get_config_int (LABEL_MAIN, LABEL_PAGE_FLIP, CONFIG_PAGE_FLIP);
       CONFIG_LANGUAGE =
-	get_config_int (LABEL_MAIN, LABEL_LANGUAGE, CONFIG_LANGUAGE);
+        get_config_int (LABEL_MAIN, LABEL_LANGUAGE, CONFIG_LANGUAGE);
       CONFIG_WAVE_ON =
-	get_config_int (LABEL_MAIN, LABEL_WAVE_ON, CONFIG_WAVE_ON);
+        get_config_int (LABEL_MAIN, LABEL_WAVE_ON, CONFIG_WAVE_ON);
       CONFIG_FRAMES_PER_SEC_LIMIT =
-	get_config_int (LABEL_MAIN, LABEL_FRAMES_PER_SEC_LIMIT,
-			CONFIG_FRAMES_PER_SEC_LIMIT);
+        get_config_int (LABEL_MAIN, LABEL_FRAMES_PER_SEC_LIMIT,
+                        CONFIG_FRAMES_PER_SEC_LIMIT);
       CONFIG_ROUNDS_PER_SEC_LIMIT =
-	get_config_int (LABEL_MAIN, LABEL_ROUNDS_PER_SEC_LIMIT,
-			CONFIG_ROUNDS_PER_SEC_LIMIT);
+        get_config_int (LABEL_MAIN, LABEL_ROUNDS_PER_SEC_LIMIT,
+                        CONFIG_ROUNDS_PER_SEC_LIMIT);
 
       strncpy (CONFIG_SERVER_ADDRESS,
-	       get_config_string (LABEL_MAIN, LABEL_SERVER_ADDRESS,
-				  CONFIG_SERVER_ADDRESS),
-	       sizeof (CONFIG_SERVER_ADDRESS));
+               get_config_string (LABEL_MAIN, LABEL_SERVER_ADDRESS,
+                                  CONFIG_SERVER_ADDRESS),
+               sizeof (CONFIG_SERVER_ADDRESS));
       CONFIG_SERVER_ADDRESS[sizeof (CONFIG_SERVER_ADDRESS) - 1] = '\0';
 
       CONFIG_SERVER_PORT =
-	get_config_int (LABEL_MAIN, LABEL_SERVER_PORT, CONFIG_SERVER_PORT);
+        get_config_int (LABEL_MAIN, LABEL_SERVER_PORT, CONFIG_SERVER_PORT);
 
       CONFIG_ASM_ALGORITHM =
-	get_config_int (LABEL_MAIN, LABEL_ASM_ALGORITHM,
-			CONFIG_ASM_ALGORITHM);
+        get_config_int (LABEL_MAIN, LABEL_ASM_ALGORITHM,
+                        CONFIG_ASM_ALGORITHM);
 
       strncpy (CONFIG_PASSWORD,
-	       get_config_string (LABEL_MAIN, LABEL_PASSWORD,
-				  CONFIG_PASSWORD), sizeof (CONFIG_PASSWORD));
+               get_config_string (LABEL_MAIN, LABEL_PASSWORD,
+                                  CONFIG_PASSWORD), sizeof (CONFIG_PASSWORD));
       CONFIG_PASSWORD[sizeof (CONFIG_PASSWORD) - 1] = '\0';
 
       CONFIG_MIN_MAP_RES =
-	get_config_int (LABEL_MAIN, LABEL_MIN_MAP_RES, CONFIG_MIN_MAP_RES);
+        get_config_int (LABEL_MAIN, LABEL_MIN_MAP_RES, CONFIG_MIN_MAP_RES);
       CONFIG_USE_DEFAULT_TEXTURE =
-	get_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
-			CONFIG_USE_DEFAULT_TEXTURE);
+        get_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
+                        CONFIG_USE_DEFAULT_TEXTURE);
       CONFIG_ALLOW_NETWORK_BOTS =
-	get_config_int (LABEL_MAIN, LABEL_ALLOW_NETWORK_BOTS,
-			CONFIG_ALLOW_NETWORK_BOTS);
+        get_config_int (LABEL_MAIN, LABEL_ALLOW_NETWORK_BOTS,
+                        CONFIG_ALLOW_NETWORK_BOTS);
+      CONFIG_LW6_ADVERTISING_SKIP =
+        get_config_int (LABEL_MAIN, LABEL_LW6_ADVERTISING_SKIP,
+                        CONFIG_LW6_ADVERTISING_SKIP);
+      CONFIG_LW6_ADVERTISING_DONE =
+        get_config_int (LABEL_MAIN, LABEL_LW6_ADVERTISING_DONE,
+                        CONFIG_LW6_ADVERTISING_DONE);
 
       return 1;
     }
@@ -534,26 +552,26 @@ save_config_options (void)
       number_string[0] = '0' + i;
 
       set_config_int (LABEL_WAVE_NUMBER, number_string,
-		      CONFIG_WAVE_NUMBER[i]);
+                      CONFIG_WAVE_NUMBER[i]);
       set_config_int (LABEL_WAVE_AMPLI, number_string, CONFIG_WAVE_AMPLI[i]);
       set_config_int (LABEL_WAVE_SPEED, number_string, CONFIG_WAVE_SPEED[i]);
     }
 
   set_config_int (LABEL_MAIN, LABEL_BRIGHTNESS, CONFIG_BRIGHTNESS);
   set_config_int (LABEL_MAIN, LABEL_CURSOR_INCREASE_SPEED,
-		  CONFIG_CURSOR_INCREASE_SPEED);
+                  CONFIG_CURSOR_INCREASE_SPEED);
   set_config_int (LABEL_MAIN, LABEL_FIGHTER_ATTACK, CONFIG_FIGHTER_ATTACK);
   set_config_int (LABEL_MAIN, LABEL_FIGHTER_DEFENSE, CONFIG_FIGHTER_DEFENSE);
   set_config_int (LABEL_MAIN, LABEL_FIGHTER_NEW_HEALTH,
-		  CONFIG_FIGHTER_NEW_HEALTH);
+                  CONFIG_FIGHTER_NEW_HEALTH);
   set_config_int (LABEL_MAIN, LABEL_NUMBER_INFLUENCE,
-		  CONFIG_NUMBER_INFLUENCE);
+                  CONFIG_NUMBER_INFLUENCE);
   set_config_int (LABEL_MAIN, LABEL_SFX_VOLUME, CONFIG_SFX_VOLUME);
   set_config_int (LABEL_MAIN, LABEL_CLICK_VOLUME, CONFIG_CLICK_VOLUME);
   set_config_int (LABEL_MAIN, LABEL_WATER_VOLUME_MENU,
-		  CONFIG_WATER_VOLUME_MENU);
+                  CONFIG_WATER_VOLUME_MENU);
   set_config_int (LABEL_MAIN, LABEL_WATER_VOLUME_GAME,
-		  CONFIG_WATER_VOLUME_GAME);
+                  CONFIG_WATER_VOLUME_GAME);
   set_config_int (LABEL_MAIN, LABEL_MUSIC_VOLUME, CONFIG_MUSIC_VOLUME);
 
   set_config_int (LABEL_MAIN, LABEL_LEVEL_MAP, CONFIG_LEVEL_MAP);
@@ -572,9 +590,9 @@ save_config_options (void)
       set_config_int (LABEL_KEY_RIGHT, number_string, CONFIG_KEY_RIGHT[i]);
       set_config_int (LABEL_TEAM_COLOR, number_string, CONFIG_TEAM_COLOR[i]);
       set_config_int (LABEL_CONTROL_TYPE, number_string,
-		      CONFIG_CONTROL_TYPE[i]);
+                      CONFIG_CONTROL_TYPE[i]);
       set_config_string (LABEL_PLAYER_NAME, number_string,
-			 CONFIG_PLAYER_NAME[i]);
+                         CONFIG_PLAYER_NAME[i]);
     }
 
   set_config_int (LABEL_MAIN, LABEL_GAME_TIME, CONFIG_GAME_TIME);
@@ -588,9 +606,9 @@ save_config_options (void)
   set_config_int (LABEL_MAIN, LABEL_WAVE_ON, CONFIG_WAVE_ON);
 
   set_config_int (LABEL_MAIN, LABEL_FRAMES_PER_SEC_LIMIT,
-		  CONFIG_FRAMES_PER_SEC_LIMIT);
+                  CONFIG_FRAMES_PER_SEC_LIMIT);
   set_config_int (LABEL_MAIN, LABEL_ROUNDS_PER_SEC_LIMIT,
-		  CONFIG_ROUNDS_PER_SEC_LIMIT);
+                  CONFIG_ROUNDS_PER_SEC_LIMIT);
 
   set_config_string (LABEL_MAIN, LABEL_SERVER_ADDRESS, CONFIG_SERVER_ADDRESS);
   set_config_int (LABEL_MAIN, LABEL_SERVER_PORT, CONFIG_SERVER_PORT);
@@ -601,9 +619,13 @@ save_config_options (void)
 
   set_config_int (LABEL_MAIN, LABEL_MIN_MAP_RES, CONFIG_MIN_MAP_RES);
   set_config_int (LABEL_MAIN, LABEL_USE_DEFAULT_TEXTURE,
-		  CONFIG_USE_DEFAULT_TEXTURE);
+                  CONFIG_USE_DEFAULT_TEXTURE);
   set_config_int (LABEL_MAIN, LABEL_ALLOW_NETWORK_BOTS,
-		  CONFIG_ALLOW_NETWORK_BOTS);
+                  CONFIG_ALLOW_NETWORK_BOTS);
+  set_config_int (LABEL_MAIN, LABEL_LW6_ADVERTISING_SKIP,
+                  CONFIG_LW6_ADVERTISING_SKIP);
+  set_config_int (LABEL_MAIN, LABEL_LW6_ADVERTISING_DONE,
+                  CONFIG_LW6_ADVERTISING_DONE);
 
   return 0;
 }
