@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -115,6 +115,8 @@ extern char CONFIG_PASSWORD[PASSWORD_SIZE + 1];
 extern int CONFIG_MIN_MAP_RES;
 extern int CONFIG_USE_DEFAULT_TEXTURE;
 extern int CONFIG_ALLOW_NETWORK_BOTS;
+extern int CONFIG_LW6_ADVERTISING_SKIP;
+extern int CONFIG_LW6_ADVERTISING_DONE;
 
 #define CONFIG_CONTROL_TYPE_OFF    0
 #define CONFIG_CONTROL_TYPE_HUMAN  1
