@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -79,9 +79,14 @@ int GFX_MODE_H[5] = { 240, 384, 480, 600, 768 };
 #endif
 
 #ifdef UNIX
+#ifdef GP2X
+int GFX_MODE_W[5] = { 320, 320, 320, 320, 320 };
+int GFX_MODE_H[5] = { 240, 240, 240, 240, 240 };
+#else
 int GFX_MODE_W[5] = { 320, 512, 640, 800, 1024 };
 int GFX_MODE_H[5] = { 240, 384, 480, 600, 768 };
 #endif
+#endif
 
 #ifdef DOS
 static int GFX_MODE_TYPE_FULLSCREEN[] = { GFX_MODEX,
@@ -90,6 +95,7 @@ static int GFX_MODE_TYPE_FULLSCREEN[] = { GFX_MODEX,
   GFX_VESA2L,
   GFX_VESA2L
 };
+
 static int GFX_MODE_TYPE_WINDOWED[] = { GFX_MODEX,
   GFX_MODEX,
   GFX_VESA2L,
@@ -105,6 +111,7 @@ static int GFX_MODE_TYPE_FULLSCREEN[] = { GFX_DIRECTX,
   GFX_DIRECTX,
   GFX_DIRECTX
 };
+
 static int GFX_MODE_TYPE_WINDOWED[] = { GFX_DIRECTX_WIN,
   GFX_DIRECTX_WIN,
   GFX_DIRECTX_WIN,
@@ -114,12 +121,28 @@ static int GFX_MODE_TYPE_WINDOWED[] = { GFX_DIRECTX_WIN,
 #endif
 
 #ifdef UNIX
+#ifdef GP2X
+static int GFX_MODE_TYPE_FULLSCREEN[] = { GFX_GP2X,
+  GFX_GP2X,
+  GFX_GP2X,
+  GFX_GP2X,
+  GFX_GP2X
+};
+
+static int GFX_MODE_TYPE_WINDOWED[] = { GFX_GP2X,
+  GFX_GP2X,
+  GFX_GP2X,
+  GFX_GP2X,
+  GFX_GP2X
+};
+#else
 static int GFX_MODE_TYPE_FULLSCREEN[] = { GFX_AUTODETECT_FULLSCREEN,
   GFX_AUTODETECT_FULLSCREEN,
   GFX_AUTODETECT_FULLSCREEN,
   GFX_AUTODETECT_FULLSCREEN,
   GFX_AUTODETECT_FULLSCREEN
 };
+
 static int GFX_MODE_TYPE_WINDOWED[] = { GFX_AUTODETECT_WINDOWED,
   GFX_AUTODETECT_WINDOWED,
   GFX_AUTODETECT_WINDOWED,
@@ -127,6 +150,7 @@ static int GFX_MODE_TYPE_WINDOWED[] = { GFX_AUTODETECT_WINDOWED,
   GFX_AUTODETECT_WINDOWED
 };
 #endif
+#endif
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -190,6 +214,10 @@ set_resolution (int res, int flip, int fullscreen, int *flip_enabled)
   int toggle;
   int i;
 
+#ifdef GP2X
+  fullscreen = 1;
+#endif
+
   if (flip_enabled)
     {
       *flip_enabled = 0;
@@ -198,35 +226,35 @@ set_resolution (int res, int flip, int fullscreen, int *flip_enabled)
   for (toggle = 0; toggle < 2; ++toggle, fullscreen = !fullscreen)
     {
       for (i = res; i >= 0 && ret; --i)
-	{
-	  if (flip)
-	    {
-	      ret = try_one_mode (i, 1, fullscreen);
-	      if (flip_enabled && !ret)
-		{
-		  *flip_enabled = 1;
-		}
-	    }
-	  if (ret)
-	    {
-	      ret = try_one_mode (i, 0, fullscreen);
-	    }
-	}
+        {
+          if (flip)
+            {
+              ret = try_one_mode (i, 1, fullscreen);
+              if (flip_enabled && !ret)
+                {
+                  *flip_enabled = 1;
+                }
+            }
+          if (ret)
+            {
+              ret = try_one_mode (i, 0, fullscreen);
+            }
+        }
       for (i = res + 1; i < 5 && ret; ++i)
-	{
-	  if (flip)
-	    {
-	      ret = try_one_mode (i, 1, fullscreen);
-	      if (flip_enabled && !ret)
-		{
-		  *flip_enabled = 1;
-		}
-	    }
-	  if (ret)
-	    {
-	      ret = try_one_mode (i, 0, fullscreen);
-	    }
-	}
+        {
+          if (flip)
+            {
+              ret = try_one_mode (i, 1, fullscreen);
+              if (flip_enabled && !ret)
+                {
+                  *flip_enabled = 1;
+                }
+            }
+          if (ret)
+            {
+              ret = try_one_mode (i, 0, fullscreen);
+            }
+        }
     }
 
   if (!ret)
@@ -234,13 +262,13 @@ set_resolution (int res, int flip, int fullscreen, int *flip_enabled)
       set_palette (black_palette);
 
       if (SCREEN_W >= 640)
-	{
-	  font = BIG_FONT;
-	}
+        {
+          font = BIG_FONT;
+        }
       else
-	{
-	  font = SMALL_FONT;
-	}
+        {
+          font = SMALL_FONT;
+        }
 
       lw_mouse_show ();
 
