@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -63,6 +63,7 @@
 #include "langdk.h"
 #include "langen.h"
 #include "langfr.h"
+#include "langpl.h"
 #include "config.h"
 
 /*==================================================================*/
@@ -79,6 +80,7 @@ lw_lang_init ()
   lw_langdk_init ();
   lw_langen_init ();
   lw_langfr_init ();
+  lw_langpl_init ();
 }
 
 /*------------------------------------------------------------------*/
@@ -98,7 +100,7 @@ lw_lang_string (int id)
     case LW_LANG_LANGUAGE_DEUTSCH:
       result = lw_langde_string (id);
       break;
-    case LW_LANG_LANGUAGE_DANISH:
+    case LW_LANG_LANGUAGE_DANSK:
       result = lw_langdk_string (id);
       break;
     case LW_LANG_LANGUAGE_ENGLISH:
@@ -107,6 +109,9 @@ lw_lang_string (int id)
     case LW_LANG_LANGUAGE_FRANCAIS:
       result = lw_langfr_string (id);
       break;
+    case LW_LANG_LANGUAGE_POLSKI:
+      result = lw_langpl_string (id);
+      break;
     }
 
   if (!result)
@@ -130,7 +135,7 @@ lw_lang_language (int lang)
     case LW_LANG_LANGUAGE_DEUTSCH:
       result = lw_langde_string (LW_LANG_STRING_LANGUAGE);
       break;
-    case LW_LANG_LANGUAGE_DANISH:
+    case LW_LANG_LANGUAGE_DANSK:
       result = lw_langdk_string (LW_LANG_STRING_LANGUAGE);
       break;
     case LW_LANG_LANGUAGE_ENGLISH:
@@ -139,6 +144,9 @@ lw_lang_language (int lang)
     case LW_LANG_LANGUAGE_FRANCAIS:
       result = lw_langfr_string (LW_LANG_STRING_LANGUAGE);
       break;
+    case LW_LANG_LANGUAGE_POLSKI:
+      result = lw_langpl_string (LW_LANG_STRING_LANGUAGE);
+      break;
     }
 
   if (!result)
@@ -170,35 +178,45 @@ lw_lang_auto ()
 
     if (env_lang != NULL)
       {
-	/*
-	 * We try and check if LANG is set to "DE..." to enable German
-	 * support.
-	 */
-	if (strncmp (env_lang, "DE", 2) == 0 ||
-	    strncmp (env_lang, "de", 2) == 0)
-	  {
-	    language = LW_LANG_LANGUAGE_DEUTSCH;
-	  }
+        /*
+         * We try and check if LANG is set to "DE..." to enable German
+         * support.
+         */
+        if (strncmp (env_lang, "DE", 2) == 0 ||
+            strncmp (env_lang, "de", 2) == 0)
+          {
+            language = LW_LANG_LANGUAGE_DEUTSCH;
+          }
 
-	/*
-	 * We try and check if LANG is set to "DK..." to enable Danish
-	 * support.
-	 */
-	if (strncmp (env_lang, "DK", 2) == 0 ||
-	    strncmp (env_lang, "dk", 2) == 0)
-	  {
-	    language = LW_LANG_LANGUAGE_DANISH;
-	  }
+        /*
+         * We try and check if LANG is set to "DK..." to enable Danish
+         * support.
+         */
+        if (strncmp (env_lang, "DK", 2) == 0 ||
+            strncmp (env_lang, "dk", 2) == 0)
+          {
+            language = LW_LANG_LANGUAGE_DANSK;
+          }
 
-	/*
-	 * We try and check if LANG is set to "FR..." to enable French
-	 * support.
-	 */
-	if (strncmp (env_lang, "FR", 2) == 0 ||
-	    strncmp (env_lang, "fr", 2) == 0)
-	  {
-	    language = LW_LANG_LANGUAGE_FRANCAIS;
-	  }
+        /*
+         * We try and check if LANG is set to "FR..." to enable French
+         * support.
+         */
+        if (strncmp (env_lang, "FR", 2) == 0 ||
+            strncmp (env_lang, "fr", 2) == 0)
+          {
+            language = LW_LANG_LANGUAGE_FRANCAIS;
+          }
+
+        /*
+         * We try and check if LANG is set to "PL..." to enable Polish
+         * support.
+         */
+        if (strncmp (env_lang, "PL", 2) == 0 ||
+            strncmp (env_lang, "pl", 2) == 0)
+          {
+            language = LW_LANG_LANGUAGE_POLSKI;
+          }
       }
   }
 #endif
@@ -213,8 +231,10 @@ lw_lang_auto ()
      * Lists of some Windows language codes, got it online:
      * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/intl/nls_238z.asp
      *
-     * 0x0406 Danish
+     * 0x0006 Danish
+     * 0x0406 Danish (Denmark)
      * 
+     * 0x000c French
      * 0x040c French (Standard) 
      * 0x080c French (Belgian) 
      * 0x0c0c French (Canadian) 
@@ -222,33 +242,44 @@ lw_lang_auto ()
      * 0x140c French (Luxembourg) 
      * 0x180c Windows 98/Me, Windows 2000/XP: French (Monaco)
      *
+     * 0x0007 German  
      * 0x0407 German (Standard) 
      * 0x0807 German (Switzerland) 
      * 0x0c07 German (Austria) 
      * 0x1007 German (Luxembourg) 
      * 0x1407 German (Liechtenstein)
+     *
+     * 0x0015 Polish
+     * 0x0415 Polisg (Poland)
      */
 
     switch (lang_id)
       {
+      case 0x0007:
       case 0x0407:
       case 0x0807:
       case 0x0c07:
       case 0x1007:
       case 0x1407:
-	language = LW_LANG_LANGUAGE_DEUTSCH;
-	break;
+        language = LW_LANG_LANGUAGE_DEUTSCH;
+        break;
+      case 0x0006:
       case 0x0406:
-	language = LW_LANG_LANGUAGE_DANISH;
-	break;
+        language = LW_LANG_LANGUAGE_DANSK;
+        break;
+      case 0x000c:
       case 0x040c:
       case 0x080c:
       case 0x0c0c:
       case 0x100c:
       case 0x140c:
       case 0x180c:
-	language = LW_LANG_LANGUAGE_FRANCAIS;
-	break;
+        language = LW_LANG_LANGUAGE_FRANCAIS;
+        break;
+      case 0x0015:
+      case 0x0415:
+        language = LW_LANG_LANGUAGE_POLSKI;
+        break;
       }
   }
 #endif
