@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -66,9 +66,10 @@
 #define LW_LANG_LANGUAGE_ENGLISH                   0
 #define LW_LANG_LANGUAGE_FRANCAIS                  1
 #define LW_LANG_LANGUAGE_DEUTSCH                   2
-#define LW_LANG_LANGUAGE_DANISH                    3
+#define LW_LANG_LANGUAGE_DANSK                    3
+#define LW_LANG_LANGUAGE_POLSKI                    4
 
-#define LW_LANG_NB_LANGUAGES                       4
+#define LW_LANG_NB_LANGUAGES                       5
 
 /*------------------------------------------------------------------*/
 /* Declaration of all available strings                             */
@@ -285,7 +286,10 @@
 #define LW_LANG_STRING_POPUP_CUSTOMFAIL          183
 #define LW_LANG_STRING_POPUP_GRAPHICSFAIL        184
 
-#define LW_LANG_NB_STRINGS                       185
+#define LW_LANG_STRING_LW6_INFO                  185
+#define LW_LANG_STRING_LW6_OK                    186
+
+#define LW_LANG_NB_STRINGS                       187
 
 /*==================================================================*/
 /* globals                                                          */
