@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -64,6 +64,7 @@
 #include "init.h"
 #include "log.h"
 #include "menu.h"
+#include "lw6.h"
 #include "parser.h"
 #include "sound.h"
 #include "startup.h"
@@ -114,30 +115,30 @@ main (int argc, char **argv)
       init_success = init_all ();
 
       if (init_success)
-	{
-	  big_data_success = (malloc_big_data () != NULL);
-	  log_println ();
-	  load_dat_success = load_dat ();
-	  log_println ();
-	  load_custom_success = load_custom ();
-	  log_println ();
+        {
+          big_data_success = (malloc_big_data () != NULL);
+          log_println ();
+          load_dat_success = load_dat ();
+          log_println ();
+          load_custom_success = load_custom ();
+          log_println ();
 
 #ifdef DOS
-	  if (STARTUP_STOP)
-	    readkey ();
-	  else
-	    delay (500);
+          if (STARTUP_STOP)
+            readkey ();
+          else
+            delay (500);
 #endif
-	}
+        }
 
       if (!init_success)
-	my_exit (EXIT_CODE_INIT_FAIL);
+        my_exit (EXIT_CODE_INIT_FAIL);
       if (!big_data_success)
-	my_exit (EXIT_CODE_BIG_DATA);
+        my_exit (EXIT_CODE_BIG_DATA);
       if (!load_dat_success)
-	my_exit (EXIT_CODE_LOAD_FAIL);
+        my_exit (EXIT_CODE_LOAD_FAIL);
       if (!load_custom_success)
-	my_exit (EXIT_CODE_CUSTOM_FAIL);
+        my_exit (EXIT_CODE_CUSTOM_FAIL);
 
       order_map ();
       check_config_range ();
@@ -146,7 +147,15 @@ main (int argc, char **argv)
 
       start_graphic ();
       start_water ();
-      main_menu ();
+      if (CONFIG_LW6_ADVERTISING_DONE || CONFIG_LW6_ADVERTISING_SKIP)
+        {
+          main_menu (1);
+        }
+      else
+        {
+          CONFIG_LW6_ADVERTISING_DONE = lw6_advertise_menu (1);
+          main_menu (0);
+        }
 
       my_exit (EXIT_CODE_OK);
     }
