@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -97,7 +97,7 @@ confirm_quit (void)
   d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITUNIX);
 #endif
   d[1].dp = lw_lang_string (LW_LANG_STRING_MENU_BACK);
-  d[0].key = 'd';
+  d[0].key = 'q';
   d[1].key = 'w';
 
   return (my_do_dialog (d, 0) == 0);
@@ -109,7 +109,7 @@ confirm_quit (void)
 
 /*------------------------------------------------------------------*/
 void
-main_menu (void)
+main_menu (int fade_in)
 {
   DIALOG d[11];
   int i, choix = 4, retour = 0;
@@ -117,17 +117,16 @@ main_menu (void)
   memset (d, 0, sizeof (d));
 
   display_back_image ();
-  /*
-     dp=my_init_dialog (d,4);
-     my_update_dialog (dp);
-     shutdown_dialog (dp);
-   */
-  my_fade_in ();
+
+  if (fade_in)
+    {
+      my_fade_in ();
+    }
 
   while (retour != MENU_EXIT)
     {
       for (i = 0; i < 6; ++i)
-	standard_button (d + i + 4, 0, i, 1, 6);
+        standard_button (d + i + 4, 0, i, 1, 6);
 
       quick_buttons (d);
       d[MENU_QUICK_BACK].flags = D_HIDDEN;
@@ -142,56 +141,56 @@ main_menu (void)
 
       choix = my_do_dialog (d, choix);
       switch (choix)
-	{
-	case -1:
-	case MENU_QUICK_QUIT:
-	  if (confirm_quit ())
-	    retour = MENU_EXIT;
-	  break;
-	case MENU_QUICK_PLAY:
-	  retour = MENU_PLAY;
-	  break;
-	case 4:
-	  LW_NETWORK_ON = 0;
-	  retour = play_sequence ();
-	  break;
-	case 5:
+        {
+        case -1:
+        case MENU_QUICK_QUIT:
+          if (confirm_quit ())
+            retour = MENU_EXIT;
+          break;
+        case MENU_QUICK_PLAY:
+          retour = MENU_PLAY;
+          break;
+        case 4:
+          LW_NETWORK_ON = 0;
+          retour = play_sequence ();
+          break;
+        case 5:
 #ifndef DOS
-	  retour = network_game ();
+          retour = network_game ();
 #else
-	  retour = error_no_network_support ();
+          retour = error_no_network_support ();
 #endif
-	  break;
-	case 6:
-	  retour = choose_map ();
-	  break;
-	case 7:
-	  retour = choose_teams ();
-	  break;
-	case 8:
-	  retour = options ();
-	  break;
-	case 9:
-	  retour = lw_about ();
-	  break;
-	}
+          break;
+        case 6:
+          retour = choose_map ();
+          break;
+        case 7:
+          retour = choose_teams ();
+          break;
+        case 8:
+          retour = options ();
+          break;
+        case 9:
+          retour = lw_about ();
+          break;
+        }
       /*
        * We handle the quick top-right "Play" button
        */
       if (retour == MENU_PLAY)
-	{
-	  if (LW_NETWORK_ON)
-	    {
+        {
+          if (LW_NETWORK_ON)
+            {
 #ifndef DOS
-	      retour = netplay_sequence ();
+              retour = netplay_sequence ();
 #else
-	      retour = play_sequence ();
+              retour = play_sequence ();
 #endif
-	    }
-	  else
-	    {
-	      retour = play_sequence ();
-	    }
-	}
+            }
+          else
+            {
+              retour = play_sequence ();
+            }
+        }
     }
 }
