@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -64,6 +64,6 @@
 /*==================================================================*/
 
 int confirm_quit (void);
-void main_menu (void);
+void main_menu (int fade_in);
 
 #endif
