@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -68,30 +68,41 @@
 /* Constants                                                        */
 /*==================================================================*/
 
+/*
+ * Following NULL-terminated list contains all versions which
+ * are compatible with current.
+ */
+static char *ACCEPTED_VERSIONS[] = { "5.6.3",
+  "5.6.4",
+  "5.6.5",
+  LW_VERSION,
+  NULL
+};
+
 /*==================================================================*/
 /* static functions                                                 */
 /*==================================================================*/
 
 static void reset (LW_SRVCHAN * chan);
 static int handle_team (LW_SRVCHAN * chan, LW_NETMESS * mess,
-			int *free_teams);
+                        int *free_teams);
 static int handle_ready (LW_SRVCHAN * chan, LW_NETMESS * mess);
 static int handle_start (LW_SRVCHAN * chan, LW_NETMESS * mess);
 static int handle_waiting (LW_SRVCHAN * chan,
-			   LW_NETMESS * mess, int free_teams);
+                           LW_NETMESS * mess, int free_teams);
 static int handle_next (LW_SRVCHAN * chan, LW_NETMESS * mess, int *next);
 static int handle_teamstartinfo (LW_SRVCHAN * chan, LW_NETMESS * mess,
-				 LW_TEAMSTARTINFO * team_start_info);
+                                 LW_TEAMSTARTINFO * team_start_info);
 static int handle_chattalk (LW_SRVCHAN * chan, LW_NETMESS * mess,
-			    LW_CHAT_HISTORY * chat);
+                            LW_CHAT_HISTORY * chat);
 static int handle_chatlisten (LW_SRVCHAN * chan, LW_NETMESS * mess);
 static int handle_who (LW_SRVCHAN * chan, LW_NETMESS * mess);
 static int handle_sendmap (LW_SRVCHAN * chan, LW_NETMESS * mess, void **map);
 static int handle_recvmap (LW_SRVCHAN * chan, LW_NETMESS * mess, void *map);
 static int handle_sendconfig (LW_SRVCHAN * chan, LW_NETMESS * mess,
-			      LW_NETCONF * config);
+                              LW_NETCONF * config);
 static int handle_recvconfig (LW_SRVCHAN * chan, LW_NETMESS * mess,
-			      LW_NETCONF * config);
+                              LW_NETCONF * config);
 
 /*------------------------------------------------------------------*/
 /*
@@ -165,13 +176,13 @@ lw_srvchan_handle_echo (int sock, LW_NETMESS * mess)
   while (i < mess->argc)
     {
       if (i == 0)
-	{
-	  LW_MACRO_STRCAT (answer, " ");
-	}
+        {
+          LW_MACRO_STRCAT (answer, " ");
+        }
       else
-	{
-	  LW_MACRO_STRCAT (answer, ",");
-	}
+        {
+          LW_MACRO_STRCAT (answer, ",");
+        }
       LW_MACRO_STRCAT (answer, mess->argv[i]);
       i++;
     }
@@ -198,10 +209,10 @@ lw_srvchan_handle_program (int sock, LW_NETMESS * mess, int *ok)
        * is not really a liquidwar client, it will be thrown away
        */
       if (strcmp (mess->argv[0], LW_PROGRAM) == 0)
-	{
-	  (*ok) = 1;
-	  result = 1;
-	}
+        {
+          (*ok) = 1;
+          result = 1;
+        }
     }
 
   /*
@@ -227,20 +238,22 @@ int
 lw_srvchan_handle_version (int sock, LW_NETMESS * mess, int *ok)
 {
   int result = 0;
+  int i = 0;
 
   if (mess->argc == 1)
     {
       /*
-       * OK, there's an argument, we check if it's the good version.
-       * This prevents form accepting random connections: if the client
-       * is not a liquidwar client with the right version number, it will
-       * be thrown away...
+       * We accept "some" versions... But cross-version connections are
+       * not recommended...
        */
-      if (strcmp (mess->argv[0], LW_VERSION) == 0)
-	{
-	  (*ok) = 1;
-	  result = 1;
-	}
+      for (i = 0; ACCEPTED_VERSIONS[i] != NULL; ++i)
+        {
+          if (strcmp (mess->argv[0], ACCEPTED_VERSIONS[i]) == 0)
+            {
+              (*ok) = 1;
+              result = 1;
+            }
+        }
     }
 
   /*
@@ -264,7 +277,7 @@ lw_srvchan_handle_version (int sock, LW_NETMESS * mess, int *ok)
  */
 int
 lw_srvchan_handle_password (int sock, LW_NETMESS * mess,
-			    int *ok, char *password)
+                            int *ok, char *password)
 {
   int result = 0;
 
@@ -275,10 +288,10 @@ lw_srvchan_handle_password (int sock, LW_NETMESS * mess,
        * OK, there's an argument, we check if it's the good password.
        */
       if (strncmp (mess->argv[0], password, PASSWORD_SIZE) == 0)
-	{
-	  (*ok) = 1;
-	  result = 1;
-	}
+        {
+          (*ok) = 1;
+          result = 1;
+        }
       break;
     }
 
@@ -349,50 +362,50 @@ handle_team (LW_SRVCHAN * chan, LW_NETMESS * mess, int *free_teams)
        */
       i = atoi (mess->argv[0]);
       if (i >= 0 && i < NB_TEAMS)
-	{
-	  if (!chan->team[i].active)
-	    {
-	      /*
-	       * The message from the client makes sense, we
-	       * return OK
-	       */
-	      result = 1;
+        {
+          if (!chan->team[i].active)
+            {
+              /*
+               * The message from the client makes sense, we
+               * return OK
+               */
+              result = 1;
 
-	      /*
-	       * Now we activate the team only if there's still
-	       * room. If not we still return OK but the "WHO"
-	       * message will later inform the client that some
-	       * of his requests have been cancelled...
-	       */
-	      if ((*free_teams) > 0)
-		{
-		  (*free_teams)--;
-		  chan->team[i].active = 1;
+              /*
+               * Now we activate the team only if there's still
+               * room. If not we still return OK but the "WHO"
+               * message will later inform the client that some
+               * of his requests have been cancelled...
+               */
+              if ((*free_teams) > 0)
+                {
+                  (*free_teams)--;
+                  chan->team[i].active = 1;
 
-		  chan->team[i].control_type = atoi (mess->argv[1]);
-		  strncpy (chan->team[i].name, mess->argv[2], NAME_SIZE);
-		  chan->team[i].name[NAME_SIZE] = '\0';
+                  chan->team[i].control_type = atoi (mess->argv[1]);
+                  strncpy (chan->team[i].name, mess->argv[2], NAME_SIZE);
+                  chan->team[i].name[NAME_SIZE] = '\0';
 
-		  log_print_str ("Team \"");
-		  log_print_str (mess->argv[2]);
-		  log_print_str ("\" on client \"");
-		  log_print_str (chan->ip);
-		  log_print_str (":");
-		  log_print_int (chan->port);
-		  log_println_str ("\" accepted");
-		}
-	      else
-		{
-		  log_print_str ("Team \"");
-		  log_print_str (mess->argv[2]);
-		  log_print_str ("\" on client \"");
-		  log_print_str (chan->ip);
-		  log_print_str (":");
-		  log_print_int (chan->port);
-		  log_println_str ("\" refused!");
-		}
-	    }
-	}
+                  log_print_str ("Team \"");
+                  log_print_str (mess->argv[2]);
+                  log_print_str ("\" on client \"");
+                  log_print_str (chan->ip);
+                  log_print_str (":");
+                  log_print_int (chan->port);
+                  log_println_str ("\" accepted");
+                }
+              else
+                {
+                  log_print_str ("Team \"");
+                  log_print_str (mess->argv[2]);
+                  log_print_str ("\" on client \"");
+                  log_print_str (chan->ip);
+                  log_print_str (":");
+                  log_print_int (chan->port);
+                  log_println_str ("\" refused!");
+                }
+            }
+        }
     }
 
   /*
@@ -428,38 +441,38 @@ handle_who (LW_SRVCHAN * chan, LW_NETMESS * mess)
        */
       i = atoi (mess->argv[0]);
       if (i >= 0 && i < NB_TEAMS)
-	{
-	  LW_MACRO_SPRINTF1 (answer, "%s", LW_NETMESS_TEXT_ERR);
+        {
+          LW_MACRO_SPRINTF1 (answer, "%s", LW_NETMESS_TEXT_ERR);
 
-	  if (chan->team[i].active)
-	    {
-	      if (chan->team[i].network)
-		{
-		  LW_MACRO_SPRINTF4 (answer,
-				     "%s %d,%d,'%s'",
-				     LW_NETMESS_TEXT_NETWORK,
-				     chan->team[i].server_id,
-				     chan->team[i].control_type,
-				     chan->team[i].name);
-		}
-	      else
-		{
-		  LW_MACRO_SPRINTF4 (answer,
-				     "%s %d,%d,'%s'",
-				     LW_NETMESS_TEXT_LOCAL,
-				     chan->team[i].server_id,
-				     chan->team[i].control_type,
-				     chan->team[i].name);
-		}
-	    }
-	  else
-	    {
-	      LW_MACRO_SPRINTF1 (answer, "%s", LW_NETMESS_TEXT_NOBODY);
-	    }
+          if (chan->team[i].active)
+            {
+              if (chan->team[i].network)
+                {
+                  LW_MACRO_SPRINTF4 (answer,
+                                     "%s %d,%d,'%s'",
+                                     LW_NETMESS_TEXT_NETWORK,
+                                     chan->team[i].server_id,
+                                     chan->team[i].control_type,
+                                     chan->team[i].name);
+                }
+              else
+                {
+                  LW_MACRO_SPRINTF4 (answer,
+                                     "%s %d,%d,'%s'",
+                                     LW_NETMESS_TEXT_LOCAL,
+                                     chan->team[i].server_id,
+                                     chan->team[i].control_type,
+                                     chan->team[i].name);
+                }
+            }
+          else
+            {
+              LW_MACRO_SPRINTF1 (answer, "%s", LW_NETMESS_TEXT_NOBODY);
+            }
 
-	  lw_sock_send_str (&(chan->sock), answer);
-	  result = 1;
-	}
+          lw_sock_send_str (&(chan->sock), answer);
+          result = 1;
+        }
     }
 
   /*
@@ -593,7 +606,7 @@ handle_next (LW_SRVCHAN * chan, LW_NETMESS * mess, int *next)
  */
 static int
 handle_teamstartinfo (LW_SRVCHAN * chan, LW_NETMESS * mess,
-		      LW_TEAMSTARTINFO * team_start_info)
+                      LW_TEAMSTARTINFO * team_start_info)
 {
   int result = 0;
   int i;
@@ -606,18 +619,18 @@ handle_teamstartinfo (LW_SRVCHAN * chan, LW_NETMESS * mess,
        */
       i = atoi (mess->argv[0]);
       if (i >= 0 && i < NB_TEAMS)
-	{
-	  LW_MACRO_SPRINTF4 (answer,
-			     "%s %d,%d,'%s'",
-			     LW_NETMESS_TEXT_OK,
-			     team_start_info[i].active,
-			     team_start_info[i].start,
-			     team_start_info[i].name);
+        {
+          LW_MACRO_SPRINTF4 (answer,
+                             "%s %d,%d,'%s'",
+                             LW_NETMESS_TEXT_OK,
+                             team_start_info[i].active,
+                             team_start_info[i].start,
+                             team_start_info[i].name);
 
-	  lw_sock_send_str (&(chan->sock), answer);
+          lw_sock_send_str (&(chan->sock), answer);
 
-	  result = 1;
-	}
+          result = 1;
+        }
     }
 
   /*
@@ -689,19 +702,19 @@ handle_chatlisten (LW_SRVCHAN * chan, LW_NETMESS * mess)
   if (mess->argc == 0)
     {
       if (lw_chat_pop (&(chan->chat), &message))
-	{
-	  /*
-	   * OK, there's a message in the queue, we send it
-	   */
-	  LW_MACRO_SPRINTF3 (answer,
-			     "%s '%s','%s'",
-			     LW_NETMESS_TEXT_OK,
-			     message.author, message.content);
-	}
+        {
+          /*
+           * OK, there's a message in the queue, we send it
+           */
+          LW_MACRO_SPRINTF3 (answer,
+                             "%s '%s','%s'",
+                             LW_NETMESS_TEXT_OK,
+                             message.author, message.content);
+        }
       else
-	{
-	  LW_MACRO_SPRINTF0 (answer, LW_NETMESS_TEXT_OK);
-	}
+        {
+          LW_MACRO_SPRINTF0 (answer, LW_NETMESS_TEXT_OK);
+        }
 
       lw_sock_send_str (&(chan->sock), answer);
 
@@ -894,8 +907,8 @@ lw_srvchan_handle_unknown (int sock, LW_NETMESS * mess)
  */
 int
 lw_srvchan_wait_teams (LW_SRVCHAN * chan, int *free_teams,
-		       int sock, void **map, LW_NETCONF * config,
-		       char *password)
+                       int sock, void **map, LW_NETCONF * config,
+                       char *password)
 {
   int result = 0;
   int ret;
@@ -916,134 +929,134 @@ lw_srvchan_wait_teams (LW_SRVCHAN * chan, int *free_teams,
       log_flush ();
 
       while ((!chan->ready_ok) && ret_mess &&
-	     ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
-	{
-	  if (ret > 0)
-	    {
-	      mess = lw_netmess_read (message);
-	      if (mess != NULL)
-		{
-		  /*
-		   * switch to handle the different possible messages
-		   */
-		  switch (mess->code)
-		    {
-		    case LW_NETMESS_CODE_PING:
-		      ret_mess = lw_srvchan_handle_ping (chan->sock, mess);
-		      break;
-		    case LW_NETMESS_CODE_ECHO:
-		      ret_mess = lw_srvchan_handle_echo (chan->sock, mess);
-		      break;
-		    case LW_NETMESS_CODE_PROGRAM:
-		      ret_mess = lw_srvchan_handle_program (chan->sock, mess,
-							    &(chan->
-							      program_ok));
-		      break;
-		    case LW_NETMESS_CODE_VERSION:
-		      ret_mess = lw_srvchan_handle_version (chan->sock, mess,
-							    &(chan->
-							      version_ok));
-		      break;
-		    case LW_NETMESS_CODE_PASSWORD:
-		      ret_mess = lw_srvchan_handle_password (chan->sock, mess,
-							     &(chan->
-							       password_ok),
-							     password);
-		      break;
-		    case LW_NETMESS_CODE_FREE:
-		      ret_mess = lw_srvchan_handle_free (chan->sock, mess,
-							 *free_teams,
-							 &free_received);
-		      break;
-		    case LW_NETMESS_CODE_TEAM:
-		      ret_mess = handle_team (chan, mess, free_teams);
-		      break;
-		    case LW_NETMESS_CODE_READY:
-		      ret_mess = handle_ready (chan, mess);
-		      break;
-		    case LW_NETMESS_CODE_SENDMAP:
-		      ret_mess = handle_sendmap (chan, mess, map);
-		      break;
-		    case LW_NETMESS_CODE_SENDCONFIG:
-		      ret_mess = handle_sendconfig (chan, mess, config);
-		      break;
-		    case LW_NETMESS_CODE_QUIT:
-		      ret_mess = lw_srvchan_handle_quit (chan->sock, mess,
-							 &(chan->
-							   normal_quit));
-		      break;
-		    default:
-		      ret_mess = lw_srvchan_handle_unknown (sock, mess);
-		      break;
-		    }
+             ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
+        {
+          if (ret > 0)
+            {
+              mess = lw_netmess_read (message);
+              if (mess != NULL)
+                {
+                  /*
+                   * switch to handle the different possible messages
+                   */
+                  switch (mess->code)
+                    {
+                    case LW_NETMESS_CODE_PING:
+                      ret_mess = lw_srvchan_handle_ping (chan->sock, mess);
+                      break;
+                    case LW_NETMESS_CODE_ECHO:
+                      ret_mess = lw_srvchan_handle_echo (chan->sock, mess);
+                      break;
+                    case LW_NETMESS_CODE_PROGRAM:
+                      ret_mess = lw_srvchan_handle_program (chan->sock, mess,
+                                                            &
+                                                            (chan->program_ok));
+                      break;
+                    case LW_NETMESS_CODE_VERSION:
+                      ret_mess = lw_srvchan_handle_version (chan->sock, mess,
+                                                            &
+                                                            (chan->version_ok));
+                      break;
+                    case LW_NETMESS_CODE_PASSWORD:
+                      ret_mess = lw_srvchan_handle_password (chan->sock, mess,
+                                                             &
+                                                             (chan->password_ok),
+                                                             password);
+                      break;
+                    case LW_NETMESS_CODE_FREE:
+                      ret_mess = lw_srvchan_handle_free (chan->sock, mess,
+                                                         *free_teams,
+                                                         &free_received);
+                      break;
+                    case LW_NETMESS_CODE_TEAM:
+                      ret_mess = handle_team (chan, mess, free_teams);
+                      break;
+                    case LW_NETMESS_CODE_READY:
+                      ret_mess = handle_ready (chan, mess);
+                      break;
+                    case LW_NETMESS_CODE_SENDMAP:
+                      ret_mess = handle_sendmap (chan, mess, map);
+                      break;
+                    case LW_NETMESS_CODE_SENDCONFIG:
+                      ret_mess = handle_sendconfig (chan, mess, config);
+                      break;
+                    case LW_NETMESS_CODE_QUIT:
+                      ret_mess = lw_srvchan_handle_quit (chan->sock, mess,
+                                                         &
+                                                         (chan->normal_quit));
+                      break;
+                    default:
+                      ret_mess = lw_srvchan_handle_unknown (sock, mess);
+                      break;
+                    }
 
-		  /*
-		   * lw_netmess_free must *not* be forgetted 
-		   */
-		  lw_netmess_free (mess);
+                  /*
+                   * lw_netmess_free must *not* be forgetted 
+                   */
+                  lw_netmess_free (mess);
 
-		  if (!ret_mess)
-		    {
-		      log_print_str ("Error processing \"");
-		      log_print_str (message);
-		      log_print_str ("\"");
-		      log_println ();
-		    }
-		}
-	      else
-		{
-		  log_println_str ("Serious memory problem 8-(");
-		  ret_mess = 0;
-		}
-	    }
-	}
+                  if (!ret_mess)
+                    {
+                      log_print_str ("Error processing \"");
+                      log_print_str (message);
+                      log_print_str ("\"");
+                      log_println ();
+                    }
+                }
+              else
+                {
+                  log_println_str ("Serious memory problem 8-(");
+                  ret_mess = 0;
+                }
+            }
+        }
 
       if (chan->program_ok &&
-	  chan->version_ok && chan->password_ok && chan->ready_ok && ret_mess)
-	{
-	  result = 1;
+          chan->version_ok && chan->password_ok && chan->ready_ok && ret_mess)
+        {
+          result = 1;
 
-	  log_print_str ("Client \"");
-	  log_print_str (chan->ip);
-	  log_print_str (":");
-	  log_print_int (chan->port);
-	  log_println_str ("\" accepted");
+          log_print_str ("Client \"");
+          log_print_str (chan->ip);
+          log_print_str (":");
+          log_print_int (chan->port);
+          log_println_str ("\" accepted");
 
-	  /* 
-	   * We play a little sound for people who have the server
-	   * opened on a console and want it to beep when someone
-	   * connects
-	   */
-	  log_beep ();
-	}
+          /* 
+           * We play a little sound for people who have the server
+           * opened on a console and want it to beep when someone
+           * connects
+           */
+          log_beep ();
+        }
       else
-	{
-	  if (chan->ready_ok)
-	    {
-	      /*
-	       * Now if we are here it means we have received a "READY"
-	       * message, but still the client did not send the correct
-	       * messages before => we send an "ERR" messageon the
-	       * network for consistency, since the client did not receive
-	       * any message to his "READY" query yet.
-	       */
-	      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
-	    }
-	  lw_sock_close (&(chan->sock));
+        {
+          if (chan->ready_ok)
+            {
+              /*
+               * Now if we are here it means we have received a "READY"
+               * message, but still the client did not send the correct
+               * messages before => we send an "ERR" messageon the
+               * network for consistency, since the client did not receive
+               * any message to his "READY" query yet.
+               */
+              lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
+            }
+          lw_sock_close (&(chan->sock));
 
-	  log_print_str ("Client \"");
-	  log_print_str (chan->ip);
-	  log_print_str (":");
-	  log_print_int (chan->port);
-	  if (chan->normal_quit)
-	    {
-	      log_println_str ("\" disconnected (probably a ping)");
-	    }
-	  else
-	    {
-	      log_println_str ("\" rejected!");
-	    }
-	}
+          log_print_str ("Client \"");
+          log_print_str (chan->ip);
+          log_print_str (":");
+          log_print_int (chan->port);
+          if (chan->normal_quit)
+            {
+              log_println_str ("\" disconnected (probably a ping)");
+            }
+          else
+            {
+              log_println_str ("\" rejected!");
+            }
+        }
     }
 
   return result;
@@ -1056,9 +1069,9 @@ lw_srvchan_wait_teams (LW_SRVCHAN * chan, int *free_teams,
  */
 int
 lw_srvchan_keepalive (LW_SRVCHAN * chan,
-		      int waited_teams,
-		      LW_TEAMSTARTINFO * team_start_info,
-		      LW_CHAT_HISTORY * chat)
+                      int waited_teams,
+                      LW_TEAMSTARTINFO * team_start_info,
+                      LW_CHAT_HISTORY * chat)
 {
   int result = 0;
   int ret;
@@ -1080,106 +1093,106 @@ lw_srvchan_keepalive (LW_SRVCHAN * chan,
   if (lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK))
     {
       while ((!chan->ready_ok) && (!next) && ret_mess &&
-	     ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
-	{
-	  if (ret > 0)
-	    {
-	      mess = lw_netmess_read (message);
-	      if (mess != NULL)
-		{
-		  /*
-		   * switch to handle the different possible messages
-		   */
-		  switch (mess->code)
-		    {
-		    case LW_NETMESS_CODE_PING:
-		      ret_mess = lw_srvchan_handle_ping (chan->sock, mess);
-		      break;
-		    case LW_NETMESS_CODE_ECHO:
-		      ret_mess = lw_srvchan_handle_echo (chan->sock, mess);
-		      break;
-		    case LW_NETMESS_CODE_START:
-		      ret_mess = handle_start (chan, mess);
-		      break;
-		    case LW_NETMESS_CODE_WAITING:
-		      ret_mess = handle_waiting (chan, mess, waited_teams);
-		      break;
-		    case LW_NETMESS_CODE_NEXT:
-		      ret_mess = handle_next (chan, mess, &next);
-		      break;
-		    case LW_NETMESS_CODE_TEAMSTARTINFO:
-		      ret_mess = handle_teamstartinfo (chan, mess,
-						       team_start_info);
-		      break;
-		    case LW_NETMESS_CODE_CHATTALK:
-		      ret_mess = handle_chattalk (chan, mess, chat);
-		      break;
-		    case LW_NETMESS_CODE_CHATLISTEN:
-		      ret_mess = handle_chatlisten (chan, mess);
-		      break;
-		    case LW_NETMESS_CODE_READY:
-		      ret_mess = handle_ready (chan, mess);
-		      break;
-		    case LW_NETMESS_CODE_QUIT:
-		      ret_mess = lw_srvchan_handle_quit (chan->sock, mess,
-							 &(chan->
-							   normal_quit));
-		      break;
-		    default:
-		      ret_mess = lw_srvchan_handle_unknown (chan->sock, mess);
-		      break;
-		    }
+             ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
+        {
+          if (ret > 0)
+            {
+              mess = lw_netmess_read (message);
+              if (mess != NULL)
+                {
+                  /*
+                   * switch to handle the different possible messages
+                   */
+                  switch (mess->code)
+                    {
+                    case LW_NETMESS_CODE_PING:
+                      ret_mess = lw_srvchan_handle_ping (chan->sock, mess);
+                      break;
+                    case LW_NETMESS_CODE_ECHO:
+                      ret_mess = lw_srvchan_handle_echo (chan->sock, mess);
+                      break;
+                    case LW_NETMESS_CODE_START:
+                      ret_mess = handle_start (chan, mess);
+                      break;
+                    case LW_NETMESS_CODE_WAITING:
+                      ret_mess = handle_waiting (chan, mess, waited_teams);
+                      break;
+                    case LW_NETMESS_CODE_NEXT:
+                      ret_mess = handle_next (chan, mess, &next);
+                      break;
+                    case LW_NETMESS_CODE_TEAMSTARTINFO:
+                      ret_mess = handle_teamstartinfo (chan, mess,
+                                                       team_start_info);
+                      break;
+                    case LW_NETMESS_CODE_CHATTALK:
+                      ret_mess = handle_chattalk (chan, mess, chat);
+                      break;
+                    case LW_NETMESS_CODE_CHATLISTEN:
+                      ret_mess = handle_chatlisten (chan, mess);
+                      break;
+                    case LW_NETMESS_CODE_READY:
+                      ret_mess = handle_ready (chan, mess);
+                      break;
+                    case LW_NETMESS_CODE_QUIT:
+                      ret_mess = lw_srvchan_handle_quit (chan->sock, mess,
+                                                         &
+                                                         (chan->normal_quit));
+                      break;
+                    default:
+                      ret_mess = lw_srvchan_handle_unknown (chan->sock, mess);
+                      break;
+                    }
 
-		  /*
-		   * lw_netmess_free must *not* be forgetted 
-		   */
-		  lw_netmess_free (mess);
+                  /*
+                   * lw_netmess_free must *not* be forgetted 
+                   */
+                  lw_netmess_free (mess);
 
-		  if (!ret_mess)
-		    {
-		      log_print_str ("Error processing \"");
-		      log_print_str (message);
-		      log_print_str ("\"");
-		      log_println ();
-		    }
-		}
-	      else
-		{
-		  log_println_str ("Serious memory problem 8-(");
-		  ret_mess = 0;
-		}
-	    }
-	}
+                  if (!ret_mess)
+                    {
+                      log_print_str ("Error processing \"");
+                      log_print_str (message);
+                      log_print_str ("\"");
+                      log_println ();
+                    }
+                }
+              else
+                {
+                  log_println_str ("Serious memory problem 8-(");
+                  ret_mess = 0;
+                }
+            }
+        }
 
       if ((chan->ready_ok || next) && ret_mess)
-	{
-	  result = 1;
-	  if (chan->ready_ok)
-	    {
-	      log_print_str ("Client \"");
-	      log_print_str (chan->ip);
-	      log_print_str (":");
-	      log_print_int (chan->port);
-	      log_println_str ("\" ready");
-	    }
-	}
+        {
+          result = 1;
+          if (chan->ready_ok)
+            {
+              log_print_str ("Client \"");
+              log_print_str (chan->ip);
+              log_print_str (":");
+              log_print_int (chan->port);
+              log_println_str ("\" ready");
+            }
+        }
       else
-	{
-	  if (chan->ready_ok || next)
-	    {
-	      /*
-	       * Now if we are here it means we have received a "READY"
-	       * message, but still the client did not send the correct
-	       * messages before => we send an "ERR" messageon the
-	       * network for consistency, since the client did not receive
-	       * any message to his "READY" query yet.
-	       */
-	      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
-	    }
-	  lw_sock_close (&(chan->sock));
+        {
+          if (chan->ready_ok || next)
+            {
+              /*
+               * Now if we are here it means we have received a "READY"
+               * message, but still the client did not send the correct
+               * messages before => we send an "ERR" messageon the
+               * network for consistency, since the client did not receive
+               * any message to his "READY" query yet.
+               */
+              lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
+            }
+          lw_sock_close (&(chan->sock));
 
-	  //log_println_str("Player KO");
-	}
+          //log_println_str("Player KO");
+        }
     }
 
   return result;
@@ -1219,84 +1232,84 @@ lw_srvchan_tell_who (LW_SRVCHAN * chan, void *map, LW_NETCONF * config)
   if (lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK))
     {
       while ((!chan->ready_ok) && ret_mess &&
-	     ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
-	{
-	  if (ret > 0)
-	    {
-	      mess = lw_netmess_read (message);
-	      if (mess != NULL)
-		{
-		  /*
-		   * switch to handle the different possible messages
-		   */
-		  switch (mess->code)
-		    {
-		    case LW_NETMESS_CODE_PING:
-		      ret_mess = lw_srvchan_handle_ping (chan->sock, mess);
-		      break;
-		    case LW_NETMESS_CODE_ECHO:
-		      ret_mess = lw_srvchan_handle_echo (chan->sock, mess);
-		      break;
-		    case LW_NETMESS_CODE_WHO:
-		      ret_mess = handle_who (chan, mess);
-		      break;
-		    case LW_NETMESS_CODE_READY:
-		      ret_mess = handle_ready (chan, mess);
-		      break;
-		    case LW_NETMESS_CODE_RECVMAP:
-		      ret_mess = handle_recvmap (chan, mess, map);
-		      break;
-		    case LW_NETMESS_CODE_RECVCONFIG:
-		      ret_mess = handle_recvconfig (chan, mess, config);
-		      break;
-		    default:
-		      ret_mess = lw_srvchan_handle_unknown (chan->sock, mess);
-		      break;
-		    }
+             ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
+        {
+          if (ret > 0)
+            {
+              mess = lw_netmess_read (message);
+              if (mess != NULL)
+                {
+                  /*
+                   * switch to handle the different possible messages
+                   */
+                  switch (mess->code)
+                    {
+                    case LW_NETMESS_CODE_PING:
+                      ret_mess = lw_srvchan_handle_ping (chan->sock, mess);
+                      break;
+                    case LW_NETMESS_CODE_ECHO:
+                      ret_mess = lw_srvchan_handle_echo (chan->sock, mess);
+                      break;
+                    case LW_NETMESS_CODE_WHO:
+                      ret_mess = handle_who (chan, mess);
+                      break;
+                    case LW_NETMESS_CODE_READY:
+                      ret_mess = handle_ready (chan, mess);
+                      break;
+                    case LW_NETMESS_CODE_RECVMAP:
+                      ret_mess = handle_recvmap (chan, mess, map);
+                      break;
+                    case LW_NETMESS_CODE_RECVCONFIG:
+                      ret_mess = handle_recvconfig (chan, mess, config);
+                      break;
+                    default:
+                      ret_mess = lw_srvchan_handle_unknown (chan->sock, mess);
+                      break;
+                    }
 
-		  /*
-		   * lw_netmess_free must *not* be forgetted 
-		   */
-		  lw_netmess_free (mess);
+                  /*
+                   * lw_netmess_free must *not* be forgetted 
+                   */
+                  lw_netmess_free (mess);
 
-		  if (!ret_mess)
-		    {
-		      log_print_str ("Error processing \"");
-		      log_print_str (message);
-		      log_print_str ("\"");
-		      log_println ();
-		    }
-		}
-	      else
-		{
-		  log_println_str ("Serious memory problem 8-(");
-		  ret_mess = 0;
-		}
-	    }
-	}
+                  if (!ret_mess)
+                    {
+                      log_print_str ("Error processing \"");
+                      log_print_str (message);
+                      log_print_str ("\"");
+                      log_println ();
+                    }
+                }
+              else
+                {
+                  log_println_str ("Serious memory problem 8-(");
+                  ret_mess = 0;
+                }
+            }
+        }
 
       if (chan->ready_ok && ret_mess)
-	{
-	  result = 1;
-	  //      log_println_str("Player OK");
-	}
+        {
+          result = 1;
+          //      log_println_str("Player OK");
+        }
       else
-	{
-	  if (chan->ready_ok)
-	    {
-	      /*
-	       * Now if we are here it means we have received a "READY"
-	       * message, but still the client did not send the correct
-	       * messages before => we send an "ERR" messageon the
-	       * network for consistency, since the client did not receive
-	       * any message to his "READY" query yet.
-	       */
-	      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
-	    }
-	  lw_sock_close (&(chan->sock));
+        {
+          if (chan->ready_ok)
+            {
+              /*
+               * Now if we are here it means we have received a "READY"
+               * message, but still the client did not send the correct
+               * messages before => we send an "ERR" messageon the
+               * network for consistency, since the client did not receive
+               * any message to his "READY" query yet.
+               */
+              lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
+            }
+          lw_sock_close (&(chan->sock));
 
-	  //log_println_str("Player KO");
-	}
+          //log_println_str("Player KO");
+        }
     }
 
   return result;
@@ -1336,9 +1349,9 @@ lw_srvchan_find_team_by_server_id (LW_SRVCHAN * chan, int server_id)
   for (i = 0; i < NB_TEAMS && result < 0; ++i)
     {
       if (chan->team[i].active && chan->team[i].server_id == server_id)
-	{
-	  result = i;
-	}
+        {
+          result = i;
+        }
     }
 
   return result;
@@ -1357,9 +1370,9 @@ lw_srvchan_find_first_free_team (LW_SRVCHAN * chan)
   for (i = 0; i < NB_TEAMS && result < 0; ++i)
     {
       if (!(chan->team[i].active))
-	{
-	  result = i;
-	}
+        {
+          result = i;
+        }
     }
 
   return result;
@@ -1403,10 +1416,10 @@ lw_srvchan_recv_keys (LW_SRVCHAN * chan, LW_NETKEY * netkey)
   for (i = 0; i < NB_TEAMS; ++i)
     {
       if (chan->team[i].active && !chan->team[i].network)
-	{
-	  netkey->key_states[chan->team[i].server_id] =
-	    chan_netkey.key_states[i];
-	}
+        {
+          netkey->key_states[chan->team[i].server_id] =
+            chan_netkey.key_states[i];
+        }
     }
 
   netkey->cmd = chan_netkey.cmd;
@@ -1434,10 +1447,10 @@ lw_srvchan_send_keys (LW_SRVCHAN * chan, LW_NETKEY * netkey)
   for (i = 0; i < NB_TEAMS; ++i)
     {
       if (chan->team[i].active)
-	{
-	  chan_netkey.key_states[i] =
-	    netkey->key_states[chan->team[i].server_id];
-	}
+        {
+          chan_netkey.key_states[i] =
+            netkey->key_states[chan->team[i].server_id];
+        }
     }
 
   chan_netkey.cmd = netkey->cmd;
