@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2007 Christian Mauduit                                 */
+/* Copyright (C) 1998-2018 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -38,7 +38,7 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 /*                                                                           */
-/* Liquid War homepage : http://www.ufoot.org/liquidwar/v5                   */
+/* Liquid War homepage : https://ufoot.org/liquidwar/v5                   */
 /* Contact author      : ufoot@ufoot.org                                     */
 /*****************************************************************************/
 
@@ -117,14 +117,30 @@ int STARTUP_CAPTURE = 0;
 int STARTUP_TOMBOLA = 0;
 
 #ifdef UNIX
+#ifdef ALLEGRO_MACOSX
+/*
+ * We test with ALLEGRO_MACOSX and no custom OSX define
+ * for this is still a variant of the UNIX port, only
+ * some paths differ (because of the .app bundle layout)
+ */
 static char *DEFAULT_CFG_PATH = CONFIG_UNIX_CFG;
 static char *DEFAULT_LOG_PATH = "";
+static char *DEFAULT_SRV_PATH = "./liquidwar-server";
+static char *DEFAULT_GEN_PATH = "./liquidwar-mapgen";
+static char *DEFAULT_DAT_PATH = "../Resources/data/liquidwar.dat";
+static char *DEFAULT_MAP_PATH = "../Resources/custom/map/";
+static char *DEFAULT_TEX_PATH = "../Resources/custom/texture/";
+static char *DEFAULT_MID_PATH = "../Resources/custom/music/";
+#else
+static char *DEFAULT_CFG_PATH = CONFIG_UNIX_CFG;
+static char *DEFAULT_LOG_PATH = "";
+static char *DEFAULT_SRV_PATH = CONFIG_UNIX_SRV;
+static char *DEFAULT_GEN_PATH = CONFIG_UNIX_GEN;
 static char *DEFAULT_DAT_PATH = CONFIG_UNIX_DAT;
 static char *DEFAULT_MAP_PATH = CONFIG_UNIX_MAP;
 static char *DEFAULT_TEX_PATH = CONFIG_UNIX_TEX;
 static char *DEFAULT_MID_PATH = CONFIG_UNIX_MID;
-static char *DEFAULT_SRV_PATH = CONFIG_UNIX_SRV;
-static char *DEFAULT_GEN_PATH = CONFIG_UNIX_GEN;
+#endif
 #else
 #ifdef WIN32
 static char *DEFAULT_CFG_PATH = "data/lwwin.cfg";
@@ -171,9 +187,9 @@ set_bigdata_size (void)
     {
       bigd = get_argument_int (IDENT_MEM);
       if (bigd < 1)
-	bigd = 1;
+        bigd = 1;
       if (bigd > LW_STARTUP_MEM_MAX)
-	bigd = LW_STARTUP_MEM_MAX;
+        bigd = LW_STARTUP_MEM_MAX;
       STARTUP_BIG_DATA = bigd;
     }
 }
@@ -292,9 +308,9 @@ correct_path_dir (char *path)
     {
       c = path[l - 1];
       if (c == '/' || c == '\\')
-	{
-	  path[--l] = 0;
-	}
+        {
+          path[--l] = 0;
+        }
     }
 
   fix_filename_case (path);
@@ -325,20 +341,20 @@ set_path (void)
 #ifdef UNIX
       home_env = getenv ("HOME");
       if (home_env != NULL)
-	{
-	  LW_MACRO_SPRINTF1 (home_path, "%s/", home_env);
-	}
+        {
+          LW_MACRO_SPRINTF1 (home_path, "%s/", home_env);
+        }
       else
-	{
-	  home_env = "";
-	  LW_MACRO_STRCPY (home_path, home_env);
-	}
+        {
+          home_env = "";
+          LW_MACRO_STRCPY (home_path, home_env);
+        }
 #else
       home_env = "";
       LW_MACRO_STRCPY (home_path, home_env);
 #endif
       LW_MACRO_SPRINTF2 (STARTUP_CFG_PATH, "%s%s", home_path,
-			 DEFAULT_CFG_PATH);
+                         DEFAULT_CFG_PATH);
     }
 
   LW_MACRO_STRCPY (STARTUP_LOG_PATH, DEFAULT_LOG_PATH);
@@ -413,7 +429,7 @@ set_metaserver (void)
   if (exist_argument_value (IDENT_METASERVER))
     {
       LW_MACRO_STRCPY (STARTUP_METASERVER,
-		       get_argument_str (IDENT_METASERVER));
+                       get_argument_str (IDENT_METASERVER));
     }
   else
     {
